==> react-native-bugsee-5.4.1.tgz: package/src/components/console.js <==
import { NativeModules } from 'react-native';
import { autoParseJson, stringify } from '../common/utils';
import { ComponentState } from '../common/componentState';
const componentState = new ComponentState({
    controlOptionName: 'CaptureLogs',
    flagName: 'logFilter',
    nativeEventName: 'bgsLogFilterEvent',
    // eslint-disable-next-line no-use-before-define
    nativeEventHandler,
    // eslint-disable-next-line no-use-before-define
    initCallback,
});
const NativeBridge = NativeModules.Bugsee;
const CONSOLE_METHODS = ['log', 'info', 'warn', 'error', 'debug', 'verbose', 'time', 'timeEnd'];
const CONSOLE_LOG_LEVELS = Object.freeze({
    log: 3,
    info: 3,
    warn: 2,
    error: 1,
    debug: 4,
    verbose: 5,
    time: 3,
    timeEnd: 3,
});
async function filterEvent(originalEvent) {
    if (componentState.launched &&
        componentState.enabled &&
        componentState.handlerSet &&
        originalEvent) {
        const { text, level, timestamp } = originalEvent;
        let filteredEvent;
        try {
            filteredEvent = await componentState.executeHandler({
                text,
                level,
            });
        }
        catch (e) {
            filteredEvent = null;
        }
        return filteredEvent ? { ...filteredEvent, timestamp } : null;
    }
    return originalEvent;
}
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function createLogEvent(args, method) {
    const text = args.map(stringify).join(' ');
    const level = CONSOLE_LOG_LEVELS[method];
    return { text, level };
}
async function handleLogEvent(logEvent) {
    if (componentState.launched && componentState.enabled) {
        const filteredEvent = await filterEvent(logEvent);
        if (filteredEvent) {
            NativeBridge.log(filteredEvent);
        }
    }
}
async function nativeEventHandler(originalEvent) {
    if (componentState.launched && componentState.enabled) {
        const parsedEvent = autoParseJson(originalEvent);
        if (parsedEvent) {
            await handleLogEvent(parsedEvent);
        }
    }
}
function initCallback(state) {
    if (!state.options?.skipPatching) {
        CONSOLE_METHODS.forEach((method) => {
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            const originalMethod = console[method];
            // eslint-disable-next-line func-names
            console[method] = function (...args) {
                if (state.launched && state.enabled) {
                    handleLogEvent(createLogEvent(args, method));
                }
                return originalMethod.apply(console, args);
            };
        });
    }
}
export default componentState;

==> react-native-bugsee-5.5.2.tgz: package/src/components/console.js <==
import { autoParseJson, stringify } from '../common/utils';
import { ComponentState } from '../common/componentState';
import { getRNBugseeModule } from '../utils/bridge';
const NativeBridge = getRNBugseeModule();
const componentState = new ComponentState({
    controlOptionName: 'CaptureLogs',
    flagName: 'logFilter',
    nativeEventName: 'bgsLogFilterEvent',
    // eslint-disable-next-line no-use-before-define
    nativeEventHandler,
    // eslint-disable-next-line no-use-before-define
    initCallback,
});
const CONSOLE_METHODS = ['log', 'info', 'warn', 'error', 'debug', 'verbose', 'time', 'timeEnd'];
const CONSOLE_LOG_LEVELS = Object.freeze({
    log: 3,
    info: 3,
    warn: 2,
    error: 1,
    debug: 4,
    verbose: 5,
    time: 3,
    timeEnd: 3,
});
async function filterEvent(originalEvent) {
    if (componentState.launched &&
        componentState.enabled &&
        componentState.handlerSet &&
        originalEvent) {
        const { text, level, timestamp } = originalEvent;
        let filteredEvent;
        try {
            filteredEvent = await componentState.executeHandler({
                text,
                level,
            });
        }
        catch (e) {
            filteredEvent = null;
        }
        return filteredEvent ? { ...filteredEvent, timestamp } : null;
    }
    return originalEvent;
}
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function createLogEvent(args, method) {
    const text = args.map(stringify).join(' ');
    const level = CONSOLE_LOG_LEVELS[method];
    return { text, level };
}
async function handleLogEvent(logEvent) {
    if (componentState.launched && componentState.enabled) {
        const filteredEvent = await filterEvent(logEvent);
        if (filteredEvent) {
            NativeBridge?.log(filteredEvent);
        }
    }
}
async function nativeEventHandler(originalEvent) {
    if (componentState.launched && componentState.enabled) {
        const parsedEvent = autoParseJson(originalEvent);
        if (parsedEvent) {
            await handleLogEvent(parsedEvent);
        }
    }
}
function initCallback(state) {
    if (!state.options?.skipPatching) {
        CONSOLE_METHODS.forEach((method) => {
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            const originalMethod = console[method];
            // eslint-disable-next-line func-names
            console[method] = function (...args) {
                if (state.launched && state.enabled) {
                    handleLogEvent(createLogEvent(args, method));
                }
                return originalMethod.apply(console, args);
            };
        });
    }
}
export default componentState;
